@@ -1,7 +1,7 @@
-__version__ = "0.2.7"
+__version__ = "0.3.0"
 
 from easydata.blocks import *  # noqa: F401 F403
-from easydata.models import ItemModel, StackedModel  # noqa: F401 F403
+from easydata.models import ItemModel, StackedModel, StackedParser  # noqa: F401 F403
 from easydata.parsers import *  # noqa: F401 F403
 from easydata.processors import *  # noqa: F401 F403
 from easydata.queries import *  # noqa: F401 F403
